<?php

namespace App\Http\Controllers\Admin\AffiliateUsers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\PromoGroup;
use Hash;

class AffiliateUsersController extends Controller
{
    
    //Affiliate Users
    public function affiliate_user_index_callback(){
        
        return view('admin.Affiliate_users.index',[
            'promo_groups' => PromoGroup::get(['id','name']),
            'affiliate_users' => User::where('id',"!=",auth()->user()->id)->with('get_promo_group')->get()
    ]);
    }
    
    // Save Into Database
    public function affiliate_user_save(Request $req){
        
        //Validation
        $req->validate([
            'email' => "unique:users",
            'password' => "min:8"
        ]);
        
        //Insertion
        $status = User::create([
        
        'firstname' => $req->firstname,
        'lastname' => $req->lastname,
        'name'     => $req->firstname ." ". $req->lastname,
        'email' => $req->email,
        'password' => Hash::make($req->password),
        'promo_group' => $req->promo_group ?? ''
        
        ]);
        
        if($status){
            session()->flash('success','Affiliate User Added Successfully');
            return back();
        }else{
            session()->flash('error','Something Went Wrong Please Try Again');
            return back();
        }
        
    }
    
    //Affiliate User Deletion
    public function affiliate_user_delete(Request $req){
        
        
            $status = User::where('id',$req->user_id)->delete();
            if($status){
                session()->flash('success','Affiliate User Deleted Successfully');
                return back();
            }else{
                session()->flash('error','Something Went Wrong . Please Try again later');
                return back();
            }
            
            
            
        
    }

    //Affiliate User Edit
    public function affiliate_user_edit($key){
        $user = User::where('id',$key)->with('get_promo_group')->first();
        return view('admin.Affiliate_users.edit',[
            'user'=>$user,
            'promo_groups' => PromoGroup::get(['id','name']),
        ]);
    }

    //Affiliate User Update
    public function affiliate_user_update(Request $req){

        //Update User
        $user  = User::where('id',$req->user_id)->update([
            'firstname' => $req->firstname, 
            'lastname' => $req->lastname,
            'name' => $req->firstname . " " . $req->lastname,
            'promo_group' => $req->promo_group ?? '',
            'email' => $req->email 
        ]);

        if($user){
            session()->flash('success','User Updated Successfully');
            return redirect('admin/affiliate-user');
        }else{
            session()->flash('error','Something Went Wrong. Please Try Again ');
            return redirect('admin/affiliate-user'); 
        }

    }
    
    
}
