<?php

namespace App\Http\Controllers\Admin\Settings;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Setting;

class SettingController extends Controller
{
    //Show Settings
    public function show_settings_callback(){
        $raw_settings = Setting::get();
        $organized_settings = [];
        foreach($raw_settings as $setting){
            $organized_settings[$setting->key] = $setting->value;
        }

        return view('admin.Settings.index',['settings'=>$organized_settings]);
    }

    //Store Settings
    public function store_settings_callback(Request $req){

        
        //Request Validation
        $req->validate([
            'stripe_public_key' => 'required|max:255',
            'stripe_secret_key' => 'required|max:255'
        ]);
        
        //Request Variable
        $stripe_public_key = $req->stripe_public_key;
        $stripe_secret_key = $req->stripe_secret_key;
        
        //Check Whether it exists already
        $stripe_public_key_db = Setting::where('key',"stripe_public_key")->where('user_id','1')->first();
        $stripe_secret_key_db = Setting::where('key',"stripe_secret_key")->where('user_id','1')->first();

        
        //Store In database
        if($stripe_public_key_db){

            //Setting in env
            env("STRIIPE_PUBLIC_KEY",$stripe_public_key);
            Setting::where('user_id','1')->where('key','stripe_public_key')->update([
                'key' => 'stripe_public_key',
                'value' => $stripe_public_key,
                'user_id' => auth()->user()->id
            ]);
            
        }else{
            //Setting in env
            env("STRIPE_PUBLIC_KEY",$stripe_public_key);
            Setting::create([
                'key' => 'stripe_public_key',
                'value' => $stripe_public_key,
                'user_id' => auth()->user()->id
            ]);
        }
        if($stripe_secret_key_db){
            //Setting in env
            env("STRIIPE_SECRET_KEY",$stripe_secret_key);
            
            Setting::where('user_id','1')->where('key','stripe_secret_key')->update([
                'key' => 'stripe_secret_key',
                'value' => $stripe_secret_key,
                'user_id' => auth()->user()->id
            ]);
            
        }else{
            //Setting in env
            env("STRIIPE_SECRET_KEY",$stripe_secret_key);
            Setting::create([
                'key' => 'stripe_secret_key',
                'value' => $stripe_secret_key,
                'user_id' => auth()->user()->id
            ]);
        }
        

        session()->flash('success','Setting Saved');
        return back();
    }
}