<?php

namespace App\Http\Controllers\Front;

use App\Http\Controllers\Controller;
use App\Models\Customer;
use App\Models\Setting;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class FrontController extends Controller
{

    public $stripe_public_key = '';
    public $stripe_secret_key = '';

    function __construct() {
        
        
        
        $this->stripe_public_key = Setting::where('key', 'stripe_public_key')->first(['value']);
        $this->stripe_secret_key = Setting::where('key', 'stripe_secret_key')->first(['value']);
        
       // if(isset($_GET['dev'])){
            // $this->stripe_public_key = Setting::where('key', 'stripe_public_key_test')->first(['value']);
            // $this->stripe_secret_key = Setting::where('key', 'stripe_secret_key_test')->first(['value']);
       // }

      }

    //index Page
    public function index_callback($key)
    {

        // if(!isset($_GET['dev']) && !(Session::has('success') || Session::has('error')) ){
            
        //     return view('maintanence');
        // }

        $user = User::findOrFail($key);
        //Retreive Stripe Setting
       

        return view('Front.front', ['affiliate_user' => $user, 'stripe_public_key' => $this->stripe_public_key->value]);
    }

    public function create_transaction(Request $req){

       
            //Retreive Stripe Setting

        //Check If Customer Already Exists Or Not
        $app_customer = Customer::where('email', $req->email)->first();

        //Stripe Client Creation
        $stripe = new \Stripe\StripeClient($this->stripe_secret_key->value);
        
        
        // Billing address details
        $billingDetails = [
            'address' => [
                'line1'       => $req->address,
                // 'line2'       => 'Apartment 4B',
                'city'        => $req->city,
                'state'       => $req->state,
                'postal_code' => $req->postcode,
                'country'     => $req->country,
            ],
            'name'    => $req->firstname . " " . $req->lastname,
            'email'   => $req->email,
            'phone'   => $req->phone,
        ];

        //Customer Creation
        $customer = $stripe->customers->create($billingDetails);

        //Customer Creation of App
        $create_app_customer = Customer::updateOrCreate(['email' => $req->email],[
            'firstname' => $req->firstname,
            'lastname' => $req->lastname,
            'fullname' => $req->firstname . ' ' . $req->lastname,
           
            'address' => $req->address,
            'payment_method_id' => '',
            'stripe_customer_id' => $customer->id,
            'affiliate_user_id' => $req->affiliate_user_id,
            'city' => $req->city,
            'country' => $req->country,
            'phone' => $req->phone,
            'promo_code' => '',
        ]);

        //Transaction Data Insertion Into Database
        $transaction = Transaction::create([
            'firstname' => $req->firstname,
            'lastname' => $req->lastname,
            'email' => $req->email,
            'address' => $req->address,
            'country' => $req->country,
            'city' => $req->city,
            'phone' => $req->phone,
            'currency' => $req->aw_currency,
            'amount' => $req->amount,
            'stripe_customer_id' => '',
            'payment_method_id' => '',
            'ip_address' => $_SERVER['REMOTE_ADDR'],
            'payment_intent_id' => '',
            'affiliate_user_id' => $req->affiliate_user_id,
            'promo_code' => $req->affiliate_user_id,
            'signature_agreement' => $req->signature_agreement == "on" ? '1' : '0',
            'signature_image' => $req->sign_img,
            'status' => 'pending',
        ]);

        $intent = $stripe->paymentIntents->create([
            'amount' => $req->amount * 100,
            'customer' => $customer->id,
            //'return_url' => "https://payment.rapidev.tech/payment/" . $req->affiliate_user_id,
            'currency' => $req->aw_currency,
            //'payment_method_data' => [
                // 'type' => 'card',
              //  'billing_details' => $billingDetails,
            //],
            // 'confirm' => true,
        ]);

       // var_dump($response);

        return   array(
            'name'=> $req->firstname . ' ' . $req->lastname,
            'email'=> $req->email,
            'client_secret'=> $intent->client_secret,
            'intent_id' => $intent->id,
            't_id' => $transaction->id
        );
    }

    public function update_transaction(Request $req){
        $t = Transaction::find($req->t_id);

        $t->reason = $req->status;
        $t->status = 'Failed';


        $t->save();

        return true;
    }

    //Store Info In Database
    public function store_payment_info_callback(Request $req)
    {
        $transaction_id = 0;

        //Request Validation
        $req->validate([
            'sign_img' => 'required',
            't_id' => 'required',
        ], [
            'sign_img.required' => "Please Provide Your Signature",
        ]);

        //Retreive Stripe Setting
       // $stripe_secret_key = Setting::where('key', 'stripe_secret_key')->first(['value']);

        //Stripe Client Creation
        $stripe = new \Stripe\StripeClient($this->stripe_secret_key->value);

        $transaction = Transaction::find($req->t_id);

        $transaction->payment_intent_id = $req->intent_id;
        $transaction->save();

        try {

                //Customer Creation of App
                $create_app_customer = Customer::updateOrCreate(['email' => $req->email],[
                    'firstname' => $req->firstname,
                    'lastname' => $req->lastname,
                    'fullname' => $req->firstname . ' ' . $req->lastname,
                    
                    'address' => $req->address,
                    'payment_method_id' => '',
                    'stripe_customer_id' => '',
                    'affiliate_user_id' => $req->affiliate_user_id,
                    'city' => $req->city,
                    'country' => $req->country,
                    'phone' => $req->phone,
                    'promo_code' => $req->affiliate_user_id,
                ]);

                $response = $stripe->paymentIntents->retrieve(
                    $req->intent_id,[]
                  );

              
              
                //Check Transaction is Successfull or Not
                if ($response->status == 'succeeded') {

                    //Update Payment Status
                    $transaction->status = "Completed";
                    $transaction->save();

                    Session::flash("success", "Payment Successfull");
                    return back();

                } else {

                    //Update Payment Status
                    $transaction->status = "Failed";
                    $transaction->save();

                    Session::flash("error", "Payment Failed");
                    return back();
                }

        } catch (\Stripe\Exception\CardException $e) {

            //Update Payment Status and store reason
            $transaction->status = "Failed";
            $transaction->reason = $e->getError()->message;
            $transaction->save();


            Session::flash("error", $e->getError()->message);
            return back();

        } catch (\Stripe\Exception\RateLimitException$e) {

            //Update Payment Status
            $transaction->status = "Failed";
            $transaction->save();

            // Too many requests made to the API too quickly
            Session::flash("error", $e->getError()->message);
            return back();

        } catch (\Stripe\Exception\InvalidRequestException$e) {

            //Update Payment Status and store reason
            $transaction->status = "Failed";
            $transaction->reason = $e->getError()->message;
            $transaction->save();

            // Invalid parameters were supplied to Stripe's API
            Session::flash("error", $e->getError()->message);
            return back();

        } catch (\Stripe\Exception\AuthenticationException$e) {

            //Update Payment Status and store reason
            $transaction->status = "Failed";
            $transaction->reason = $e->getError()->message;
            $transaction->save();

            // Authentication with Stripe's API failed
            // (maybe you changed API keys recently)
            Session::flash("error", $e->getError()->message);
            return back();

        } catch (\Stripe\Exception\ApiConnectionException$e) {

            //Update Payment Status and store reason
            $transaction->status = "Failed";
            $transaction->reason = $e->getError()->message;
            $transaction->save();
            // Network communication with Stripe failed
            Session::flash("error", $e->getError()->message);
            return back();

        } catch (\Stripe\Exception\ApiErrorException$e) {

            //Update Payment Status and store reason
            $transaction->status = "Failed";
            $transaction->reason = $e->getError()->message;
            $transaction->save();

            Session::flash("error", $e->getError()->message);
            return back();

        } catch (\Exception $e) {

            //Update Payment Status and store reason
            $transaction->status = "Failed";
            $transaction->reason = $e->getMessage();
            $transaction->save();

            Session::flash("error", 'Payment Failed');
            return back();

        }
    }
}
